#include "kinectreader.h"
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>

KinectReader::KinectReader(const std::string directoryName) {

    this->sequenceName = directoryName;

    struct dirent **direct;
    int n = scandir(sequenceName.c_str(), &direct, 0, alphasort);

    if(n == 0) {

        std::cout << "Unable to open directory!" << std::endl;
        exit(-1);

    } else {
        for(int i = 0; i < n; ++i) {
            if(strstr(direct[i]->d_name,".jpg")) {

                filenameRGB.push_back(std::string(direct[i]->d_name));

            }

        }
    }

    if(filenameRGB.size() == 0) {
        std::cout << "Error: No files found!" << std::endl;
        exit(-1);
    }

    int pos = filenameRGB[0].find("_RGB_");

    baseName = filenameRGB[0].substr(0, pos);

    frameCounter = 0;
    double delay = (1/30) * 2000000;

}

KinectReader::~KinectReader() {}

bool KinectReader::getData() {

    if(frameCounter == filenameRGB.size())
        return false;

    std::stringstream searchTime;
    searchTime << "_" << frameCounter << "_";

    int idx = -1;
    for(int i = 0; i < filenameRGB.size(); ++i) {
        if(strstr(filenameRGB[i].c_str(), searchTime.str().c_str()) != NULL) {
            idx = i;
            break;
        }
    }


    int pos1 = filenameRGB[idx].find(searchTime.str().c_str()) + searchTime.str().length();
    int pos2 = filenameRGB[idx].find(".jpg") - pos1;

    timestamp = atoi(filenameRGB[idx].substr(pos1, pos2).c_str());

    std::stringstream name;
    name << sequenceName << "/" << baseName << "_RGB_" << frameCounter<<  "_" << timestamp << ".jpg" ;

    frame = cv::imread(name.str());

    frameNumber.str(std::string());
    cv::rectangle(frame, cv::Point(10, 2), cv::Point(100,20), cv::Scalar(255,255,255), -1);
    frameNumber << frameCounter;
    cv::putText(frame, frameNumber.str().c_str(), cv::Point(15, 15), CV_FONT_NORMAL, 0.5 , cv::Scalar(0,0,0));

    int width = frame.cols;
    int height = frame.rows;

    name.str(std::string());
    name << sequenceName << "/" << baseName << "_DEPTH_" << frameCounter << ".png" ;

    depthMat16bit = cv::imread(name.str(), CV_16UC1);

    cv::Mat adjMap;
    depth = cv::Mat::zeros(depthMat16bit.size(), CV_8UC3);
    depthMat16bit.convertTo(adjMap, CV_8UC1, 255.0/2048.0);
    applyColorMap(adjMap, depth, cv::COLORMAP_JET);

    ++frameCounter;

    usleep(delay);

    return true;

}
