#include "kinectwriter.h"



KinectWriter::KinectWriter(const std::string sequenceName, bool view, const int ndevice) {

    this->sequenceName = sequenceName;

    this->view = view;

    width = 640;
    height = 480;

    depthMat16bit = cv::Mat(cv::Size(width,height),CV_16UC1);
    depth = cv::Mat(cv::Size(width,height),CV_8UC3);
    frame = cv::Mat(cv::Size(width,height),CV_8UC3,cv::Scalar(0));
	
	device = &freenect.createDevice<MyFreenectDevice>(ndevice);
	
   	device->startVideo();
   	device->startDepth();
    frameCounter = 0;
	initial_tick_count = (double)cv::getTickCount();

    twoK = false;
}

KinectWriter::KinectWriter(const std::string sequenceName, const std::string directory, bool view, const int ndevice) {

    this->sequenceName = sequenceName;

    this->view = view;

    width = 640;
    height = 480;

    depthMat16bit = cv::Mat(cv::Size(width,height),CV_16UC1);
    depth = cv::Mat(cv::Size(width,height),CV_8UC3);
    frame = cv::Mat(cv::Size(width,height),CV_8UC3,cv::Scalar(0));

    device = &freenect.createDevice<MyFreenectDevice>(ndevice);

    device->startVideo();
    device->startDepth();
    frameCounter = 0;
    initial_tick_count = (double)cv::getTickCount();

    this->directory = directory;

    twoK = true;
}


KinectWriter::~KinectWriter() {
    device->stopVideo();
    device->stopDepth();
	freenect.deleteDevice(0);
	delete device;
}

inline unsigned long KinectWriter::getTimestamp() {
    struct timeval tv;
    gettimeofday(&tv,0);
    return (unsigned long)(tv.tv_sec%86400)*1000+(unsigned long)tv.tv_usec/1000;
}


void KinectWriter::write() {
    cv::imwrite(nameRGB.str().c_str(), frame);
    cv::imwrite(nameDepth.str().c_str(), depthMat16bit);
}


bool KinectWriter::getData() {
	nameRGB.clear();
	nameRGB.str("");
	
    if(device->getVideo(frame)) {
        device->getDepth(depthMat16bit);
        if(!view) {
            unsigned long timestamp = getTimestamp() - initial_tick_count;
            (!twoK) ? nameRGB << sequenceName << "_RGB_" << frameCounter << "_" << timestamp << ".jpg" :
                      nameRGB << directory << "/" << sequenceName << "_RGB_" << frameCounter << "_" << timestamp << ".jpg";
            (!twoK) ? nameDepth << sequenceName << "_DEPTH_" << frameCounter << ".png":
                      nameDepth << directory << "/" << sequenceName << "_DEPTH_" << frameCounter << ".png";
            if(!twoK) {
                cv::imwrite(nameRGB.str().c_str(), frame);
                cv::imwrite(nameDepth.str().c_str(), depthMat16bit);
            }
        }

        cv::Mat adjMap;
        depth = cv::Mat::zeros(depthMat16bit.size(), CV_8UC3);
        depthMat16bit.convertTo(adjMap, CV_8UC1, 255.0/2048.0);
        applyColorMap(adjMap, depth, cv::COLORMAP_JET);

        frameCounter++;
        return true;
    }
    else
        return false;
}
